@@ -18,6 +18,6 @@ my $hello = Wasm::Wasmtime::Func->new(
   sub { print "hello world!\n" },
 );
 
-my $instance = Wasm::Wasmtime::Instance->new($module, [$hello]);
+my $instance = Wasm::Wasmtime::Instance->new($module, $store, [$hello]);
 $instance->exports->run->call(); # hello world!
 
