@@ -12,16 +12,18 @@ use Devel::GlobalDestruction ();
 use base qw( Exporter );
 
 # ABSTRACT: Private class for Wasm::Wasmtime
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
-our @EXPORT = qw( $ffi $ffi_prefix _generate_vec_class _generate_destroy _ver_0_19_0 );
+our @EXPORT = qw( $ffi $ffi_prefix _generate_vec_class _generate_destroy );
 
 sub _lib
 {
-  my $lib = find_lib lib => 'wasmtime';
+  my $lib = find_lib lib => 'wasmtime', symbol => ['wasmtime_func_as_funcref'];
   return $lib if $lib;
-  return find_lib lib => 'wasmtime', alien => 'Alien::wasmtime';
+  $lib = find_lib lib => 'wasmtime', alien => 'Alien::wasmtime', symbol => ['wasmtime_func_as_funcref'];
+  return $lib if $lib;
+  die 'unable to find wasmtime 0.19.0 or better';
 }
 
 our $ffi_prefix = 'wasm_';
@@ -34,15 +36,6 @@ $ffi->mangler(sub {
   return $ffi_prefix . $name;
 });
 
-sub _ver_0_19_0
-{
-  # ugly hack.  Since wasmtime doesn't have an interface for giving us its version
-  # we look for symbols that were in 0.19.0 but not in 0.18.0.  We can remove this
-  # when we later require 0.19.0.
-  # See also: https://github.com/perlwasm/Wasm/issues/75
-  !!$ffi->find_symbol('wasmtime_func_as_funcref');
-}
-
 { package Wasm::Wasmtime::Vec;
   use FFI::Platypus::Record;
   record_layout_1(
@@ -270,7 +263,7 @@ Wasm::Wasmtime::FFI - Private class for Wasm::Wasmtime
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
