@@ -13,7 +13,7 @@ use Ref::Util qw( is_ref is_blessed_ref is_plain_coderef is_plain_scalarref );
 use Carp ();
 
 # ABSTRACT: Wasmtime instance class
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 $ffi_prefix = 'wasm_instance_';
@@ -64,6 +64,16 @@ $ffi->attach( [ wasmtime_instance_new => 'new' ] => ['wasm_store_t','wasm_module
   my $xsub = shift;
   my $class = shift;
   my $module = shift;
+  my $store = is_blessed_ref($_[0]) && $_[0]->isa('Wasm::Wasmtime::Store')
+    ? shift
+    : do {
+      if(warnings::enabled("deprecated"))
+      {
+        Carp::carp('Creating a Wasm::Wasmtime::Instance instance without a Wasm::Wasmtime::Store object is deprecated and will be removed in a future version of Wasm::Wasmtime');
+      }
+      no warnings 'deprecated';
+      $module->store;
+    };
 
   my $ptr;
   my @keep;
@@ -85,7 +95,6 @@ $ffi->attach( [ wasmtime_instance_new => 'new' ] => ['wasm_store_t','wasm_module
     Carp::confess("imports is not an array reference") unless ref($imports) eq 'ARRAY';
     my @imports = @$imports;
     my $trap;
-    my $store = $module->store;
 
     {
       my @mi = @{ $module->imports };
@@ -107,7 +116,7 @@ $ffi->attach( [ wasmtime_instance_new => 'new' ] => ['wasm_store_t','wasm_module
       if($trap)
       {
         $trap = Wasm::Wasmtime::Trap->new($trap);
-        Carp::croak($trap->message);
+        die $trap;
       }
       else
       {
@@ -154,14 +163,15 @@ Wasm::Wasmtime::Instance - Wasmtime instance class
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
  use Wasm::Wasmtime;
  
- my $module = Wasm::Wasmtime::Module->new(wat => '(module)');
- my $instance = Wasm::Wasmtime::Instance->new($module, []);
+ my $store = Wasm::Wasmtime::Store->new;
+ my $module = Wasm::Wasmtime::Module->new($store, wat => '(module)');
+ my $instance = Wasm::Wasmtime::Instance->new($module, $store, []);
 
 =head1 DESCRIPTION
 
@@ -174,9 +184,21 @@ This class represents an instance of a WebAssembly module L<Wasm::Wasmtime::Modu
 
 =head2 new
 
+ my $instance = Wasm::Wasmtime::Instance->new(
+   $module,    # Wasm::Wasmtime::Module
+   $store      # Wasm::Wasmtime::Store
+ );
+ my $instance = Wasm::Wasmtime::Instance->new(
+   $module,    # Wasm::Wasmtime::Module
+   $store,     # Wasm::Wasmtime::Store
+   \@imports,  # array reference of Wasm::Wasmtime::Extern
+ );
+ 
+ # deprecated usage: without $store
  my $instance = Wasm::Wasmtime::Instance->new(
    $module     # Wasm::Wasmtime::Module
  );
+ # deprecated usage: without $store
  my $instance = Wasm::Wasmtime::Instance->new(
    $module,    # Wasm::Wasmtime::Module
    \@imports,  # array reference of Wasm::Wasmtime::Extern
@@ -205,6 +227,12 @@ access it from Perl space, but at least it won't die.
 
 =back
 
+[B<Deprecated>: Will be removed in a future version of L<Wasm::Wasmtime>]
+
+You can create an L<Wasm::Wasmtime::Instance> instance without a
+L<Wasm::Wasmtime::Store> object, but this usage is deprecated, and will
+be removed from a future version of L<Wasm::Wasmtime>.
+
 =head1 METHODS
 
 =head2 module
