@@ -14,7 +14,7 @@ use Ref::Util qw( is_blessed_ref );
 use Carp ();
 
 # ABSTRACT: Wasmtime linker class
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 $ffi_prefix = 'wasmtime_linker_';
@@ -87,12 +87,12 @@ $ffi->attach( instantiate => ['wasmtime_linker_t','wasm_module_t','opaque*','opa
   if($trap)
   {
     $trap = Wasm::Wasmtime::Trap->new($trap);
-    Carp::croak($trap->message);
+    die $trap;
   }
   elsif($ptr)
   {
     return Wasm::Wasmtime::Instance->new(
-      $module, $ptr,
+      $module, $self->store, $ptr,
     );
   }
   else
@@ -135,7 +135,7 @@ Wasm::Wasmtime::Linker - Wasmtime linker class
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
