@@ -13,7 +13,7 @@ use Wasm::Wasmtime::ExportType;
 use Carp ();
 
 # ABSTRACT: Wasmtime module class
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 $ffi_prefix = 'wasm_module_';
@@ -64,34 +64,17 @@ sub _args
 }
 
 
-if(_ver_0_19_0())
-{
-  $ffi->attach( [ wasmtime_module_new => 'new' ] => ['wasm_engine_t', 'wasm_byte_vec_t*', 'opaque*'] => 'wasmtime_error_t' => sub {
-    my $xsub = shift;
-    my $class = shift;
-    my($store, $wasm, $data) = _args(@_);
-    my $ptr;
-    if(my $error = $xsub->($store->engine, $$wasm, \$ptr))
-    {
-      Carp::croak("error creating module: " . $error->message);
-    }
-    bless { ptr => $ptr, store => $store }, $class;
-  });
-}
-else
-{
-  $ffi->attach( [ wasmtime_module_new => 'new' ] => ['wasm_store_t', 'wasm_byte_vec_t*', 'opaque*'] => 'wasmtime_error_t' => sub {
-    my $xsub = shift;
-    my $class = shift;
-    my($store, $wasm, $data) = _args(@_);
-    my $ptr;
-    if(my $error = $xsub->($store, $$wasm, \$ptr))
-    {
-      Carp::croak("error creating module: " . $error->message);
-    }
-    bless { ptr => $ptr, store => $store }, $class;
-  });
-}
+$ffi->attach( [ wasmtime_module_new => 'new' ] => ['wasm_engine_t', 'wasm_byte_vec_t*', 'opaque*'] => 'wasmtime_error_t' => sub {
+  my $xsub = shift;
+  my $class = shift;
+  my($store, $wasm, $data) = _args(@_);
+  my $ptr;
+  if(my $error = $xsub->($store->engine, $$wasm, \$ptr))
+  {
+    Carp::croak("error creating module: " . $error->message);
+  }
+  bless { ptr => $ptr, store => $store }, $class;
+});
 
 $ffi->attach( [ wasmtime_module_validate => 'validate' ] => ['wasm_store_t', 'wasm_byte_vec_t*'] => 'wasmtime_error_t' => sub {
   my $xsub = shift;
@@ -130,7 +113,18 @@ $ffi->attach( [ imports => '_imports' ] => [ 'wasm_module_t', 'wasm_importtype_v
 });
 
 
-sub store { shift->{store} }
+sub engine { shift->{store}->engine }
+
+
+sub store
+{
+  my($self) = @_;
+  if(warnings::enabled("deprecated"))
+  {
+    Carp::carp('The store method for the Wasm::Wasmtime::Module class is deprecated and will be removed in a future version of Wasm::Wasmtime');
+  }
+  $self->{store};
+}
 
 
 sub to_string
@@ -162,7 +156,7 @@ Wasm::Wasmtime::Module - Wasmtime module class
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -249,10 +243,18 @@ Returns a L<Wasm::Wasmtime::Module::Exports> object that can be used to query th
 
 Returns a list of L<Wasm::Wasmtime::ImportType> objects for the objects imported by the WebAssembly module.
 
+=head2 engine
+
+ my $engine = $module->engine;
+
+Returns the L<Wasm::Wasmtime::Engine> object used by this module.
+
 =head2 store
 
  my $store = $module->store;
 
+[B<Deprecated>: Will be removed in a future version of L<Wasm::Wasmtime>]
+
 Returns the L<Wasm::Wasmtime::Store> object used by this module.
 
 =head2 to_string
